==> sgq-business-0.3-sources.jar: com/herbocailleau/sgq/business/services/csv/BatchImportModel.java <==
/*
 * #%L
 * SGQ :: Business
 * $Id: BatchImportModel.java 113 2012-10-02 14:38:07Z echatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/sgq-ch/tags/sgq-ch-0.3/sgq-business/src/main/java/com/herbocailleau/sgq/business/services/csv/BatchImportModel.java $
 * %%
 * Copyright (C) 2012 Herboristerie Cailleau
 * %%
 * Herboristerie Cailleau - Tous droits réservés
 * #L%
 */

package com.herbocailleau.sgq.business.services.csv;

import static org.nuiton.i18n.I18n._;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.util.csv.ValueParser;
import org.nuiton.util.csv.ext.AbstractImportModel;

import com.herbocailleau.sgq.business.SgqBusinessException;
import com.herbocailleau.sgq.entities.Batch;
import com.herbocailleau.sgq.entities.BatchImpl;
import com.herbocailleau.sgq.entities.Client;
import com.herbocailleau.sgq.entities.Country;
import com.herbocailleau.sgq.entities.Product;
import com.herbocailleau.sgq.entities.Supplier;

/**
 * Modèle d'import du fichier CSV du fichier numero lot (ancien fichier
 * excel circulant dans l'herboristerie cailleau , faisant office de
 * référence et contenant des informations corrigées par rapport au fichier
 * dbase).
 * 
 * "DATE_R";"CODE_FOUR_R";"FOUR_R";"COMM_R";"COLIS_R";"POIDS_R";"PRO_R";"PAYS_R";
 * "CODE_PAYS_R";"LOT_R";"DLUO_R";"CLI_R";"CODE_CLI_R";"ECH_R";"REM_R";"IGNORER"
 * 
 * @author echatellier
 */
public class BatchImportModel extends AbstractImportModel<Batch> {

    private static final Log log = LogFactory.getLog(BatchImportModel.class);

    public BatchImportModel(final Map<String, Supplier> suppliers,
            final Map<String, Client> clients, final Map<String, Product> products) {
        super(';');
        newMandatoryColumn("DATE_R", Batch.PROPERTY_ENTRY_DATE, new ValueParser<Date>() {
            protected DateFormat df = new SimpleDateFormat("dd/MM/yyyy");
            @Override
            public Date parse(String value) throws ParseException {
                return df.parse(value);
            }
        });
        newMandatoryColumn("CODE_FOUR_R", Batch.PROPERTY_SUPPLIER, new ValueParser<Supplier>() {
            @Override
            public Supplier parse(String value) throws ParseException {
                Supplier supplier = suppliers.get(value);
                if (supplier == null) {
                    throw new SgqBusinessException(_("Impossible de trouver le fournisseur %s", value));
                }
                return supplier;
            }
        });
        newIgnoredColumn("FOUR_R");
        newMandatoryColumn("COMM_R", Batch.PROPERTY_ORDER_NUMBER, new ValueParser<Integer>() {
            @Override
            public Integer parse(String value) throws ParseException {
                return Integer.valueOf(value);
            }
        });
        newMandatoryColumn("COLIS_R", Batch.PROPERTY_PACKAGE_COUNT, new ValueParser<Integer>() {
            @Override
            public Integer parse(String value) throws ParseException {
                return Integer.valueOf(value);
            }
        });
        newMandatoryColumn("POIDS_R", Batch.PROPERTY_QUANTITY, new ValueParser<Double>() {
            @Override
            public Double parse(String value) throws ParseException {
                return Double.valueOf(value.replace(',','.').replaceAll("[^\\d.]",""));
            }
        });
        newMandatoryColumn("PRO_R", Batch.PROPERTY_PRODUCT, new ValueParser<Product>() {
            @Override
            public Product parse(String value) throws ParseException {
                if (value.startsWith(".")) {
                    value = StringUtils.removeStart(value, ".");
                }
                Product product = products.get(value);
                if (product == null) {
                    throw new SgqBusinessException(_("Impossible de trouver le produit %s ", value));
                }
                return product;
            }
        });
        newIgnoredColumn("PAYS_R");
        newMandatoryColumn("CODE_PAYS_R", Batch.PROPERTY_ORIGIN, new ValueParser<Country>() {
            @Override
            public Country parse(String value) throws ParseException {
                return Country.valueOf(value);
            }
        });
        newMandatoryColumn("LOT_R", Batch.PROPERTY_NUMBER, new ValueParser<Integer>() {
            @Override
            public Integer parse(String value) throws ParseException {
                return Integer.valueOf(value);
            }
        });
        newMandatoryColumn("DLUO_R", Batch.PROPERTY_DLUO, new ValueParser<Date>() {
            protected DateFormat df = new SimpleDateFormat("dd/MM/yyyy");
            @Override
            public Date parse(String value) throws ParseException {
                return df.parse(value);
            }
        });
        newIgnoredColumn("CLI_R");
        newMandatoryColumn("CODE_CLI_R", Batch.PROPERTY_DEDICATED_CLIENT, new ValueParser<Client>() {
            @Override
            public Client parse(String value) throws ParseException {
                Client client = null;
                // il n'est pas obligatoire que le lot soit dédié à un client
                if (StringUtils.isNotBlank(value)) {
                    client = clients.get(value);
                    if (client == null) {
                        throw new SgqBusinessException(_("Impossible de trouver le client %s", value));
                    }
                }
                return client;
            }
        });
        newMandatoryColumn("ECH_R", Batch.PROPERTY_SAMPLE_CODE);
        newMandatoryColumn("REM_R", Batch.PROPERTY_COMMENT);
        newMandatoryColumn("IGNORER", Batch.PROPERTY_INVALID, new ValueParser<Boolean>() {
            // si cette colonne est valuée, toute la ligne doit être ingorée
            @Override
            public Boolean parse(String value) throws ParseException {
                if (StringUtils.isNotBlank(value)) {
                    throw new SgqBusinessException(_("Ligne ingorée : %s", value));
                }
                return Boolean.FALSE;
            }
        });
    }

    @Override
    public Batch newEmptyInstance() {
        return new BatchImpl();
    }
}

==> sgq-business-0.4-sources.jar: com/herbocailleau/sgq/business/services/csv/BatchImportModel.java <==
/*
 * #%L
 * SGQ :: Business
 * $Id: BatchImportModel.java 141 2012-10-08 14:34:53Z echatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/sgq-ch/tags/sgq-ch-0.4/sgq-business/src/main/java/com/herbocailleau/sgq/business/services/csv/BatchImportModel.java $
 * %%
 * Copyright (C) 2012 Herboristerie Cailleau
 * %%
 * Herboristerie Cailleau - Tous droits réservés
 * #L%
 */

package com.herbocailleau.sgq.business.services.csv;

import static org.nuiton.i18n.I18n._;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.util.csv.ValueParser;
import org.nuiton.util.csv.ext.AbstractImportModel;

import com.herbocailleau.sgq.business.SgqBusinessException;
import com.herbocailleau.sgq.business.SgqUtils;
import com.herbocailleau.sgq.entities.Batch;
import com.herbocailleau.sgq.entities.BatchImpl;
import com.herbocailleau.sgq.entities.Client;
import com.herbocailleau.sgq.entities.Country;
import com.herbocailleau.sgq.entities.Product;
import com.herbocailleau.sgq.entities.Supplier;

/**
 * Modèle d'import du fichier CSV du fichier numero lot (ancien fichier
 * excel circulant dans l'herboristerie cailleau , faisant office de
 * référence et contenant des informations corrigées par rapport au fichier
 * dbase).
 * 
 * "DATE_R";"CODE_FOUR_R";"FOUR_R";"COMM_R";"COLIS_R";"POIDS_R";"PRO_R";"PAYS_R";
 * "CODE_PAYS_R";"LOT_R";"DLUO_R";"CLI_R";"CODE_CLI_R";"ECH_R";"REM_R";"IGNORER"
 * 
 * @author echatellier
 */
public class BatchImportModel extends AbstractImportModel<Batch> {

    private static final Log log = LogFactory.getLog(BatchImportModel.class);

    public BatchImportModel(final Map<String, Supplier> suppliers,
            final Map<String, Client> clients, final Map<String, Product> products) {
        super(';');
        newMandatoryColumn("DATE_R", Batch.PROPERTY_ENTRY_DATE, new ValueParser<Date>() {
            @Override
            public Date parse(String value) throws ParseException {
                return SgqUtils.parseSgqDate(value);
            }
        });
        newMandatoryColumn("CODE_FOUR_R", Batch.PROPERTY_SUPPLIER, new ValueParser<Supplier>() {
            @Override
            public Supplier parse(String value) throws ParseException {
                Supplier supplier = suppliers.get(value);
                if (supplier == null) {
                    throw new SgqBusinessException(_("Impossible de trouver le fournisseur %s", value));
                }
                return supplier;
            }
        });
        newIgnoredColumn("FOUR_R");
        newMandatoryColumn("COMM_R", Batch.PROPERTY_ORDER_NUMBER, new ValueParser<Integer>() {
            @Override
            public Integer parse(String value) throws ParseException {
                return Integer.valueOf(value);
            }
        });
        newMandatoryColumn("COLIS_R", Batch.PROPERTY_PACKAGE_COUNT, new ValueParser<Integer>() {
            @Override
            public Integer parse(String value) throws ParseException {
                return Integer.valueOf(value);
            }
        });
        newMandatoryColumn("POIDS_R", Batch.PROPERTY_QUANTITY, new ValueParser<Double>() {
            @Override
            public Double parse(String value) throws ParseException {
                return Double.valueOf(value.replace(',','.').replaceAll("[^\\d.]",""));
            }
        });
        newMandatoryColumn("PRO_R", Batch.PROPERTY_PRODUCT, new ValueParser<Product>() {
            @Override
            public Product parse(String value) throws ParseException {
                if (value.startsWith(".")) {
                    value = StringUtils.removeStart(value, ".");
                }
                Product product = products.get(value);
                if (product == null) {
                    throw new SgqBusinessException(_("Impossible de trouver le produit %s ", value));
                }
                return product;
            }
        });
        newIgnoredColumn("PAYS_R");
        newMandatoryColumn("CODE_PAYS_R", Batch.PROPERTY_ORIGIN, new ValueParser<Country>() {
            @Override
            public Country parse(String value) throws ParseException {
                return Country.valueOf(value);
            }
        });
        newMandatoryColumn("LOT_R", Batch.PROPERTY_NUMBER, new ValueParser<Integer>() {
            @Override
            public Integer parse(String value) throws ParseException {
                return Integer.valueOf(value);
            }
        });
        newMandatoryColumn("DLUO_R", Batch.PROPERTY_DLUO, new ValueParser<Date>() {
            @Override
            public Date parse(String value) throws ParseException {
                return SgqUtils.parseSgqDate(value);
            }
        });
        newIgnoredColumn("CLI_R");
        newMandatoryColumn("CODE_CLI_R", Batch.PROPERTY_DEDICATED_CLIENT, new ValueParser<Client>() {
            @Override
            public Client parse(String value) throws ParseException {
                Client client = null;
                // il n'est pas obligatoire que le lot soit dédié à un client
                if (StringUtils.isNotBlank(value)) {
                    client = clients.get(value);
                    if (client == null) {
                        throw new SgqBusinessException(_("Impossible de trouver le client %s", value));
                    }
                }
                return client;
            }
        });
        newMandatoryColumn("ECH_R", Batch.PROPERTY_SAMPLE_CODE);
        newMandatoryColumn("REM_R", Batch.PROPERTY_COMMENT);
        newMandatoryColumn("IGNORER", Batch.PROPERTY_INVALID, new ValueParser<Boolean>() {
            // si cette colonne est valuée, toute la ligne doit être ingorée
            @Override
            public Boolean parse(String value) throws ParseException {
                if (StringUtils.isNotBlank(value)) {
                    throw new SgqBusinessException(_("Ligne ignorée : %s", value));
                }
                return Boolean.FALSE;
            }
        });
        newMandatoryColumn("Date épuissé", Batch.PROPERTY_EXPIRED_DATE, new ValueParser<Date>() {
            @Override
            public Date parse(String value) throws ParseException {
                Date result = null;
                // la date peut être vide (=pas épuisé)
                if (StringUtils.isNotBlank(value)) {
                    result = SgqUtils.parseSgqDate(value);
                }
                return result;
            }
        });
    }

    @Override
    public Batch newEmptyInstance() {
        return new BatchImpl();
    }
}
